function zero_contour_search

format compact
sprintf('*********************************************\n'),

Rmin = 1;
Rmax = 8000;
alphaMin = .01;
alphaMax = 2.5;

ptNo = 1;
while ptNo <= 20,
    sprintf('New search point! \nPoint no: %d\n',ptNo),
    
    lambda = 1;
    dR = 10;
    dalpha = .01;
    
    R = Rmin + (Rmax-Rmin)*rand;
    alpha = alphaMin + (alphaMax-alphaMin)*rand;
    
    isConverge = 1;
    lastg = 1;
    iterNo = 0;
    while abs(lastg) > 1e-5,
        g = lambda * imag(search_c(R, alpha));
        
        g_R = lambda * imag(search_c(R+dR, alpha));
        g_alpha = lambda * imag(search_c(R, alpha+dalpha));
    
        dg_dR = (g_R - g)/dR;
        dg_dalpha = (g_alpha - g)/dalpha;
    
        if abs(dg_dR) < 1e-3 & abs(dg_dalpha) < 1e-3      %Flat g-surface 
            lambda = 2/sqrt(abs(dg_dR*dg_dalpha));                  % Adaptive lambda
            sprintf('WARNING: Problem in convergence (Flat g-surface).... using adaptive lambda! lambda = %d', lambda),
        elseif abs(dg_dR) > 100 | abs(dg_dalpha) > 100    %Steep g-surface 
            lambda = sqrt(abs(dg_dR*dg_dalpha))/2;                  % Adaptive lambda
            sprintf('WARNING: Problem in convergence (Steep g-surface).... using adaptive lambda! lambda = %d', lambda),
        else
            newR = R - g/dg_dR;
            newalpha = alpha - g/dg_dalpha;
            if g*lastg < 0
                R = (R + newR)/2;
                alpha = (alpha + newalpha)/2;
            elseif abs(g) < abs(lastg)
                R = newR;
                alpha = newalpha;
            else
                R = (R + newR)/2;
                alpha = (alpha + newalpha)/2;
                sprintf('WARNING: Suspecting local extreama'),
                %sprintf('ERROR: Divergence detected.... attempting once again afresh!\n'),
                %isConverge = 0;
                %break
            end
            lambda = 1;
        end
        
        lastg = g;
        
        iterNo = iterNo + 1;
        if iterNo > 50
            sprintf('ERROR: No convergence could be achieved in 50 iterations.... attempting once again afresh!\n'),
            isConverge = 0;
            break
        end
        sprintf('iterNo = %d  ,  g = %d', iterNo, g),
    end
    
    if isConverge == 1
        Rs(ptNo) = R;
        alphas(ptNo) = alpha;
        ptNo = ptNo + 1;
        sprintf('** Convergence achieved in %d iterations \n****************************************\n', iterNo),
    end
end

save 'C:\Documents and Settings\Subhrajit.SELF-37D14AD783\My Documents\B.Tech Project\Matlab\Solution\zero_contour_randomSearch_20pts_high_precision.mat' Rs alphas;

axis([0 log10(8000) 0 2.5]);
plot(log10(Rs), alphas,'.');
